@@ -46,7 +46,7 @@ DEFAULT_SPECD_PATH = os.path.join(
     os.path.dirname(__file__), "../../gosdk/specs/"
 )
 
-VERSION = "0.9.21"
+VERSION = "0.9.22"
 COPYRIGHT = "Copyright: GenomOncology, LLC"
 
 
@@ -165,9 +165,10 @@ def from_bed(state, gene_column, skip_comment, comment_char):
 )
 @click.option("--skip_comment", type=bool, default=False)
 @click.option("--comment_char", type=str, default="#")
+@click.option("--include_header", type=bool, default=True)
 @options.build_option
 @options.pass_state
-def from_tsv(state, columns, skip_comment, comment_char):
+def from_tsv(state, columns, skip_comment, comment_char, include_header):
     """Parses TSV into name-value pair objects."""
     return [
         sources.DelimitedFileSource(
@@ -176,6 +177,7 @@ def from_tsv(state, columns, skip_comment, comment_char):
             build=state.build,
             skip_comment=skip_comment,
             comment_char=comment_char,
+            include_header=include_header,
         )
     ]
 
@@ -423,11 +425,26 @@ def annotate_calls(
     help="Include homozygous reference and unknown calls.",
     is_flag=True,
 )
+@click.option(
+    "--hgvs_batch",
+    "-h",
+    "hgvs_batch",
+    help="Input is a batch of g. or c. strings instead of CALL or VARIANT "
+    "object",
+    is_flag=True,
+)
 @options.size_option
 @options.build_option
 @options.pass_state
 @options.timeout_option
-def annotate_match(state, timeout, run_async, delete_if_exists, keep_ref_unknown_calls):
+def annotate_match(
+    state,
+    timeout,
+    run_async,
+    delete_if_exists,
+    keep_ref_unknown_calls,
+    hgvs_batch,
+):
     """Get annotations for stream of calls."""
     if run_async:
         create_function = kms.create_async_processor
@@ -458,6 +475,7 @@ def annotate_match(state, timeout, run_async, delete_if_exists, keep_ref_unknown
             delete_if_exists=delete_if_exists,
             build=state.build,
             annotation_bundle_version=annotation_bundle_version,
+            hgvs_batch=hgvs_batch,
         ),
         concat,
     ]
