@@ -18,11 +18,10 @@ def filter_del_lines_from_load_annotations(call):
 
 
 def filter_bnd_cpx_ctx_lns_from_load_annotations(call):
-    """If the dict[alt] is not equal to any of the unwanteds then return true
-    so that the filter option will gather all of the lines that were
-    considered true and dispose the lines that are false. Essentially we
-    are leveraging the filter() funciton to remove any lines with
-     alt==unwanted"""
-
-    unwanteds = ("<BND>", "<CPX>", "<CTX>")
-    return call.get("alt", "") not in unwanteds
+    """If the dict['mutation_type'] is not equal to any of the unwanteds then
+    return true so that the filter option will gather all of the lines that
+    were considered true and dispose the lines that are false. Essentially we
+    are leveraging the filter() function to remove any lines where
+     'mutation_type'==unwanted"""
+    unwanteds = ("BND", "CPX", "CTX")
+    return call.get("mutation_type", "") not in unwanteds
