@@ -85,8 +85,14 @@ async def async_annotate_match(
     delete_if_exists=False,
     build=GRCh37,
     annotation_bundle_version=None,
+    hgvs_batch=False,
 ):
-    csra_batch = convert_to_csra([{**d, "build": build} for d in data])
+    # Check if input data is just a list of hashes or genes
+    if hgvs_batch or all(type(d) == str for d in data):
+        csra_batch = list(data)
+    # Otherwise input data is a list of VARIANT_CALL or some other datatype
+    else:
+        csra_batch = convert_to_csra([{**d, "build": build} for d in data])
 
     if csra_batch:
         annotations_list = await sdk.call_with_retry(
@@ -99,14 +105,14 @@ async def async_annotate_match(
         annotations_list = None
 
     annotated_calls = annotate_match_calls(
-        annotations_list, data, annotation_bundle_version
+        annotations_list, data, annotation_bundle_version, hgvs_batch
     )
 
     logger.get_logger().debug(
         "async_annotate_match",
         call_count=len(data),
         first_call=data[:1],
-        csra_batch=csra_batch[:4],
+        csra_batch=csra_batch[:4] if csra_batch else None,
         annotated_count=len(annotated_calls),
         first_annotated=annotated_calls[:1],
     )
@@ -121,8 +127,14 @@ def sync_annotate_match(
     delete_if_exists=False,
     build=GRCh37,
     annotation_bundle_version=None,
+    hgvs_batch=False,
 ):
-    csra_batch = convert_to_csra([{**d, "build": build} for d in data])
+    # Check if input data is just a list of hashes or genes
+    if hgvs_batch or all(type(d) == str for d in data):
+        csra_batch = list(data)
+    # Otherwise input data is a list of VARIANT_CALL or some other datatype
+    else:
+        csra_batch = convert_to_csra([{**d, "build": build} for d in data])
 
     annotations_list = (
         sdk.call_with_retry(
@@ -136,7 +148,7 @@ def sync_annotate_match(
     )
 
     annotated_calls = annotate_match_calls(
-        annotations_list, data, annotation_bundle_version
+        annotations_list, data, annotation_bundle_version, hgvs_batch
     )
 
     logger.get_logger().debug(
@@ -209,7 +221,8 @@ def sync_annotate_sv_match(
         if record["__type__"] != "HEADER":
             if record.get("mutation_type") not in SV_MUTATION_TYPES:
                 msg = (
-                    f"unknown SVTYPE of '{record.get('mutation_type', None)}'\n"
+                    f"unknown SVTYPE of "
+                    f"'{record.get('mutation_type', None)}'\n"
                     f"\t(expected valid SVTYPEs {SV_MUTATION_TYPES})\n"
                     "Annotations SV Match Process Terminated"
                 )
@@ -399,14 +412,55 @@ def annotate_hotspots(data):
     return annotations
 
 
-def annotate_match_calls(annotations_list, data, annotation_bundle_version):
-    func = partial(
-        add_annotation_match, annotations_list, annotation_bundle_version
-    )
+def annotate_match_calls(
+    annotations_list, data, annotation_bundle_version, hgvs_batch
+):
+    if hgvs_batch:
+        func = partial(
+            add_annotation_hgvs_match,
+            annotations_list,
+            annotation_bundle_version,
+        )
+    else:
+        func = partial(
+            add_annotation_match, annotations_list, annotation_bundle_version
+        )
     annotated_calls = list(map(func, data))
     return annotated_calls
 
 
+# This method is used to format the API result if the input is a batch of
+# raw hgvs_g/hgvs_c variant strings instead of CALL or VARIANT doctypes
+def add_annotation_hgvs_match(
+    annotations_list: AnnotationMatchList, expected_bundle_version, call: str
+):
+    annotations = {}
+    if annotations_list:
+        annotations = (
+            obj_to_dict(None, annotations_list.get_annotation(call)) or {}
+        )
+        if expected_bundle_version is not None:
+
+            actual_bundle_version = (
+                annotations.get("annotation_bundle_version")
+                or expected_bundle_version
+            )
+
+            if expected_bundle_version != actual_bundle_version:
+                msg = (
+                    "Annotations Process Terminated due to "
+                    "annotations_bundle_version "
+                    "changing during a run. \n"
+                    "Expected annotation bundle version: {expected} \n"
+                    "Actual annotation bundle version: {actual}".format(
+                        expected=expected_bundle_version,
+                        actual=actual_bundle_version,
+                    )
+                )
+                raise AnnBundleVersionAssertionError(msg)
+    return annotations
+
+
 def add_annotation_match(
     annotations_list: AnnotationMatchList, expected_bundle_version, call: dict
 ):  # pragma: no mccabe
