@@ -106,14 +106,27 @@ class HistoricalVcfFileSink(FileSink):
     def handle_gene_annotations(
         self, info_dict, gene_annotations, alt_index=None
     ):
-        # loop through all gene annotations and add them in the format
-        # {ann_key_name}__{gene_name}=value. This way, we can successfully
-        # handle variants that span across multiple genes.
-        for gene_ann in gene_annotations:
+        if type(gene_annotations) == list:
+            self.format_gene_annotations(
+                gene_annotations,
+                info_dict,
+                alt_index
+            )
+        else:
+            for gene_annotation_key, gene_anns in gene_annotations.items():
+                self.format_gene_annotations(
+                    gene_anns,
+                    info_dict,
+                    alt_index
+                )
+
+    def format_gene_annotations(self, gene_anns, info_dict, alt_index=None):
+        for gene_ann in gene_anns:
             gene_name = gene_ann.pop("gene", "")
             if gene_ann:
                 for k, v in gene_ann.items():
-                    key = self.handle_key("%s__%s" % (k, gene_name), alt_index)
+                    key = self.handle_key("%s__%s" % (k, gene_name),
+                                          alt_index)
                     value = self.handle_value(v)
                     if value:
                         info_dict[key] = value
