@@ -7,7 +7,7 @@ from .aggregated import (
     AggregatedCOSMICSources,
     AggregatedFileSource,
     AggregatedOmimFileSource,
-    AggregatedCOSMICNonSNVSources
+    AggregatedCOSMICNonSNVSources,
 )
 from .maf import MAFSource
 from .xml import XMLSource
