@@ -1,4 +1,5 @@
 import copy
+import re
 from cytoolz.curried import curry, assoc
 from cytoolz import reduceby
 
@@ -262,6 +263,7 @@ class AggregatedOmimFileSource(LazyFileSource):
             "file_path": self.name,
         }
 
+
 @curry
 class AggregatedCOSMICNonSNVSources(LazyFileSource):
     """
@@ -277,6 +279,7 @@ class AggregatedCOSMICNonSNVSources(LazyFileSource):
         record_type = Click.choice(["cnv", "fusion"])
     and this controls which file we are expecting to receive
     """
+
     def __init__(self, filename, record_type, include_header=True, **meta):
         self.cosmic_tsv = filename
         self.include_header = include_header
@@ -323,8 +326,11 @@ class AggregatedCOSMICNonSNVSources(LazyFileSource):
 
     def aggregate_cnv_record(self, merged_dict, cnv_row):
         if "_E" not in cnv_row["gene_name"]:
-            mut_type = "Amplification" if cnv_row['MUT_TYPE'] == "gain" \
-                else cnv_row['MUT_TYPE'].title()
+            mut_type = (
+                "Amplification"
+                if cnv_row["MUT_TYPE"] == "gain"
+                else cnv_row["MUT_TYPE"].title()
+            )
 
             alteration = f"{cnv_row['gene_name']} {mut_type}"
             aggregated_cnv_record = merged_dict.setdefault(
@@ -340,7 +346,7 @@ class AggregatedCOSMICNonSNVSources(LazyFileSource):
                     "HISTOLOGY_SUBTYPE": {},
                     "HISTOLOGY_SUBTYPE_FREQ": {},
                     "ID_SAMPLE": [],
-                    "chr": cnv_row["Chromosome:G_Start..G_Stop"]
+                    "chr": cnv_row["Chromosome:G_Start..G_Stop"],
                 },
             )
 
@@ -350,12 +356,15 @@ class AggregatedCOSMICNonSNVSources(LazyFileSource):
             merged_dict[alteration] = aggregated_cnv_record
 
     def aggregate_fusion_record(self, merged_dict, fusion_row):
-        if "_ENTS" not in fusion_row["3'_GENE_NAME"] and "_ENTS" not in fusion_row["5'_GENE_NAME"]:
-            gene = fusion_row["3'_GENE_NAME"]
-            partner = fusion_row["5'_GENE_NAME"]
+        if (
+            "_ENTS" not in fusion_row["3'_GENE_NAME"]
+            and "_ENTS" not in fusion_row["5'_GENE_NAME"]
+        ):
+            gene = re.sub("_\S*", "", fusion_row["3'_GENE_NAME"])
+            partner = re.sub("_\S*", "", fusion_row["5'_GENE_NAME"])
             alteration = (
                 f"{gene}-{partner} Fusion",
-                f"{partner}-{gene} Fusion"
+                f"{partner}-{gene} Fusion",
             )
 
             if merged_dict.get((alteration[::-1])):
@@ -373,15 +382,17 @@ class AggregatedCOSMICNonSNVSources(LazyFileSource):
                     "HISTOLOGY_FREQ": {},
                     "HISTOLOGY_SUBTYPE": {},
                     "HISTOLOGY_SUBTYPE_FREQ": {},
-                    "ID_SAMPLE": []
+                    "ID_SAMPLE": [],
                 },
             )
             aggregated_fusion_record = self.aggregate(
-                aggregated_fusion_record, fusion_row, alteration, self.record_type
+                aggregated_fusion_record,
+                fusion_row,
+                alteration,
+                self.record_type,
             )
             merged_dict[alteration] = aggregated_fusion_record
 
-
     def aggregate(self, agg, x, alteration, record_type):  # pragma: no mccabe
         # COSMIC cnv and fusion .tsv files have different headers for each row
         # This differentiates between what keys we should be using to accession
@@ -392,7 +403,7 @@ class AggregatedCOSMICNonSNVSources(LazyFileSource):
             SITE_SUBTYPES = [
                 "Site subtype 1",
                 "Site subtype 2",
-                "Site subtype 3"
+                "Site subtype 3",
             ]
             PRIMARY_HISTOLOGY = "Primary histology"
             HISTOLOGY_SUBTYPES = [
@@ -407,7 +418,7 @@ class AggregatedCOSMICNonSNVSources(LazyFileSource):
             SITE_SUBTYPES = [
                 "SITE_SUBTYPE_1",
                 "SITE_SUBTYPE_2",
-                "SITE_SUBTYPE_3"
+                "SITE_SUBTYPE_3",
             ]
             PRIMARY_HISTOLOGY = "PRIMARY_HISTOLOGY"
             HISTOLOGY_SUBTYPES = [
@@ -441,10 +452,10 @@ class AggregatedCOSMICNonSNVSources(LazyFileSource):
                 raise Exception(
                     f"TSV data error. Sample ID {x.get(ID_SAMPLE)} "
                     f"contains more than one value for Gene name. Values "
-                    f"found are: {agg['gene_name']} and {[x.get('gene_name')]}."
+                    f"found are: {agg['gene_name']} and "
+                    f"{[x.get('gene_name')]}."
                 )
 
-
         # add the sample ID to the aggregated dict
         id_sample = x.get(ID_SAMPLE)
         if id_sample not in agg["ID_SAMPLE"]:
@@ -470,10 +481,13 @@ class AggregatedCOSMICNonSNVSources(LazyFileSource):
                 agg["TISSUES"][x.get(PRIMARY_SITE)] = 1
 
             # Puts together aggregates for information regarding site subtypes
-            # Subtypes are structured as <histology_site_value>/<hist_subtype_n>
+            # Subtypes are structured as:
+            # <histology_site_value>/<hist_subtype_n>
             for field in HISTOLOGY_SUBTYPES:
                 if x.get(field) and x.get(field) != "NS":
-                    subtype_string = x.get(PRIMARY_HISTOLOGY) + "/" + x.get(field)
+                    subtype_string = (
+                        x.get(PRIMARY_HISTOLOGY) + "/" + x.get(field)
+                    )
                     if subtype_string in agg["HISTOLOGY_SUBTYPE"]:
                         agg["HISTOLOGY_SUBTYPE"][subtype_string] += 1
                     else:
@@ -487,7 +501,6 @@ class AggregatedCOSMICNonSNVSources(LazyFileSource):
 
         return agg
 
-
     def process_tissue_freqs(self, cosmic_dict):
         for ck, cv in cosmic_dict.items():
             for k, v in cv["TISSUES"].items():
@@ -1117,7 +1130,7 @@ COSMIC_TSV_CNV_COLUMNS = [
     "MUT_TYPE",
     "ID_STUDY",
     "GRCh",
-    "Chromosome:G_Start..G_Stop"
+    "Chromosome:G_Start..G_Stop",
 ]
 
 COSMIC_TSV_FUSION_COLUMNS = [
@@ -1152,5 +1165,5 @@ COSMIC_TSV_FUSION_COLUMNS = [
     "3'_GENOME_STOP_FROM",
     "3'_GENOME_STOP_TO",
     "FUSION_TYPE",
-    "PUBMED_PMID"
+    "PUBMED_PMID",
 ]
