@@ -4,10 +4,7 @@ from genomoncology.parse.doctypes import DocType, __TYPE__, __CHILD__
 from genomoncology.pipeline.transformers import name_mapping
 from genomoncology.pipeline.transformers.registry import register
 
-NAME_MAPPING = {
-    "gene": "gene",
-    "hgnc_id": "hgncID"
-}
+NAME_MAPPING = {"gene": "gene", "hgnc_id": "hgncID"}
 
 
 register(
