@@ -16,6 +16,12 @@ def parse_hpo_gene(x):
     return x["key"]
 
 
+def dedupe_gene_id(x):
+    gene_ids = x.get("gene_id", None)
+    if gene_ids:
+        return list(set(gene_ids))
+
+
 register(
     input_type=DocType.AGGREGATE,
     output_type=DocType.HPO,
@@ -23,6 +29,7 @@ register(
         lambda x: assoc(x, "is_gene_annotation", True),
         lambda x: assoc(x, __TYPE__, DocType.HPO.value),
         name_mapping(NAME_MAPPING),
+        lambda x: assoc(x, "gene_id", dedupe_gene_id(x)),
         lambda x: assoc(x, "gene", parse_hpo_gene(x)),
     ),
 )
