@@ -7,7 +7,7 @@ NAME_MAPPING = {
     "gene": "gene",
     "disease_name__string": "disease_name",
     "disease_mim__string": "disease_mim",
-    "gene_mim": "MIM"
+    "gene_mim": "MIM",
 }
 
 
